@@ -46,7 +46,7 @@ def cat_check(raw_data):
 	return regex_support(raw_data, "Domain ID:")
 
 def com_check(raw_data):
-	return regex_support(raw_data, "Domain Name:")
+	return ~regex_support(raw_data, "No match for") + 2
 
 def regex_support(raw_data, regex_word):
 	regex = re.compile(regex_word)
